@@ -1,5 +1,6 @@
 import logging
 import ssl
+import json
 from os import path
 from pathlib import Path
 from time import sleep
@@ -369,15 +370,17 @@ class TLSTransport:
                     )
                 ]
             )
-            self.store.tls_state.session_resumption_tickets = (
-                native_openssl.SSL_SESSION_has_ticket(conn.get_session()._session) == 1
-            )
-            self.store.tls_state.session_resumption_ticket_hint = (
-                native_openssl.SSL_SESSION_get_ticket_lifetime_hint(
-                    conn.get_session()._session
+            if hasattr(native_openssl, 'SSL_SESSION_has_ticket'):
+                self.store.tls_state.session_resumption_tickets = (
+                    native_openssl.SSL_SESSION_has_ticket(conn.get_session()._session) == 1
+                )
+            if hasattr(native_openssl, 'SSL_SESSION_get_ticket_lifetime_hint'):
+                self.store.tls_state.session_resumption_ticket_hint = (
+                    native_openssl.SSL_SESSION_get_ticket_lifetime_hint(
+                        conn.get_session()._session
+                    )
+                    > 0
                 )
-                > 0
-            )
             self.store.tls_state.expected_client_subjects = [
                 ",".join(f"{name.decode()}={value.decode()}".strip())
                 for subject in conn.get_client_ca_list()
